@@ -3,7 +3,7 @@
 # Start Date:   Sat, 24 Aug 1996 22:08:19 +0200
 # Project:      INN 
 # File:         innshellvars.pl
-# RCSId:        $Id: innshellvars.pl.in,v 1.9 2002/09/16 17:38:03 rra Exp $
+# RCSId:        $Id: innshellvars.pl.in 7466 2005-12-12 03:04:08Z eagle $
 # Description:  Set up any and all variables that an INN perl script
 #               might need.
 
@@ -78,6 +78,8 @@ $perl = "/usr/bin/perl" ;
 $pgp = "" ;
 $sort = "/usr/bin/sort" ;
 $getftp = "/usr/bin/wget" ;
+$uux = "/usr/bin/uux" ;
+
 $compress = "/usr/bin/compress" ;
 $gzip = "/usr/bin/gzip" ;
 $uncompress = "/usr/bin/compress -d" ;
@@ -106,6 +108,9 @@ $umask = 02 ;
 $syslog_facility = lc("LOG_NEWS");
 $syslog_facility =~ s/log_//;
 
+$ENV{'PATH'} ||= '';
 $ENV{'PATH'} = "${newslbin}:${newsbin}:$ENV{'PATH'}:/bin:/usr/bin:/usr/ucb" ;
 
+$ENV{'HOME'} = ${pathnews};
+
 1 ;
